pub struct MeUpdateBuilder<C> { /* private fields */ }Expand description
Builder for the update_me method.
Implementations
Sourceimpl<C> MeUpdateBuilder<C>
impl<C> MeUpdateBuilder<C>
Sourcepub fn new(client: C) -> MeUpdateBuilder<C>
pub fn new(client: C) -> MeUpdateBuilder<C>
Creates a builder with the client.
Sourcepub fn as_request(&self) -> &Request
pub fn as_request(&self) -> &Request
Gets the request object for reuse.
Sourcepub fn set_name(&mut self, name: impl Into<String>) -> &mut MeUpdateBuilder<C>
pub fn set_name(&mut self, name: impl Into<String>) -> &mut MeUpdateBuilder<C>
Sets the name.
Sourcepub fn delete_name(&mut self) -> &mut MeUpdateBuilder<C>
pub fn delete_name(&mut self) -> &mut MeUpdateBuilder<C>
Deletes the name.
Sourcepub fn set_description(
&mut self,
description: impl Into<String>,
) -> &mut MeUpdateBuilder<C>
pub fn set_description( &mut self, description: impl Into<String>, ) -> &mut MeUpdateBuilder<C>
Sets the description.
Sourcepub fn delete_description(&mut self) -> &mut MeUpdateBuilder<C>
pub fn delete_description(&mut self) -> &mut MeUpdateBuilder<C>
Deletes the description.
Sourcepub fn set_language(
&mut self,
language: impl Into<String>,
) -> &mut MeUpdateBuilder<C>
pub fn set_language( &mut self, language: impl Into<String>, ) -> &mut MeUpdateBuilder<C>
Sets the language.
Sourcepub fn delete_language(&mut self) -> &mut MeUpdateBuilder<C>
pub fn delete_language(&mut self) -> &mut MeUpdateBuilder<C>
Deletes the language.
Sourcepub fn set_location(
&mut self,
location: impl Into<String>,
) -> &mut MeUpdateBuilder<C>
pub fn set_location( &mut self, location: impl Into<String>, ) -> &mut MeUpdateBuilder<C>
Sets the location.
Sourcepub fn delete_location(&mut self) -> &mut MeUpdateBuilder<C>
pub fn delete_location(&mut self) -> &mut MeUpdateBuilder<C>
Deletes the location.
Sourcepub fn set_birthday(
&mut self,
birthday: impl Into<String>,
) -> &mut MeUpdateBuilder<C>
pub fn set_birthday( &mut self, birthday: impl Into<String>, ) -> &mut MeUpdateBuilder<C>
Sets the birthday.
Sourcepub fn delete_birthday(&mut self) -> &mut MeUpdateBuilder<C>
pub fn delete_birthday(&mut self) -> &mut MeUpdateBuilder<C>
Deletes the birthday.
Sourcepub fn set_avatar(
&mut self,
avatar: impl EntityRef<DriveFile>,
) -> &mut MeUpdateBuilder<C>
pub fn set_avatar( &mut self, avatar: impl EntityRef<DriveFile>, ) -> &mut MeUpdateBuilder<C>
Sets the avatar.
Sourcepub fn delete_avatar(&mut self) -> &mut MeUpdateBuilder<C>
pub fn delete_avatar(&mut self) -> &mut MeUpdateBuilder<C>
Deletes the avatar.
Sets the banner.
Deletes the banner.
Sourcepub fn set_pinned_page(
&mut self,
pinned_page: impl EntityRef<Page>,
) -> &mut MeUpdateBuilder<C>
pub fn set_pinned_page( &mut self, pinned_page: impl EntityRef<Page>, ) -> &mut MeUpdateBuilder<C>
Sets the pinned page.
Sourcepub fn delete_pinned_page(&mut self) -> &mut MeUpdateBuilder<C>
pub fn delete_pinned_page(&mut self) -> &mut MeUpdateBuilder<C>
Deletes the pinned page.
Sourcepub fn set_fields(
&mut self,
fields: impl IntoUserFields,
) -> &mut MeUpdateBuilder<C>
pub fn set_fields( &mut self, fields: impl IntoUserFields, ) -> &mut MeUpdateBuilder<C>
Sets the fields in this user’s profile.
Since the user has four fields, it takes an array of length 1 to 4 as its argument.
Examples
client
.update_me()
.set_fields([
("Website", "https://example.com/"),
("Twitter", "@username"),
])
.update()
.await?;Sourcepub fn delete_fields(&mut self) -> &mut MeUpdateBuilder<C>
pub fn delete_fields(&mut self) -> &mut MeUpdateBuilder<C>
Deletes all the fields in this user’s profile.
Sourcepub fn locked(&mut self, locked: bool) -> &mut MeUpdateBuilder<C>
pub fn locked(&mut self, locked: bool) -> &mut MeUpdateBuilder<C>
Sets whether this user is locked or not.
Sourcepub fn explorable(&mut self, explorable: bool) -> &mut MeUpdateBuilder<C>
Available on crate feature 12-63-0 only.
pub fn explorable(&mut self, explorable: bool) -> &mut MeUpdateBuilder<C>
12-63-0 only.Sets whether this user is visible in “Explore” section of the instance.
Sourcepub fn require_follow_request_for_bot(
&mut self,
require_follow_request_for_bot: bool,
) -> &mut MeUpdateBuilder<C>
pub fn require_follow_request_for_bot( &mut self, require_follow_request_for_bot: bool, ) -> &mut MeUpdateBuilder<C>
Sets whether this user requires a follow request from bots.
Sourcepub fn auto_accept_followed(
&mut self,
auto_accept_followed: bool,
) -> &mut MeUpdateBuilder<C>
pub fn auto_accept_followed( &mut self, auto_accept_followed: bool, ) -> &mut MeUpdateBuilder<C>
Sets whether to automatically accept follow requests from following users.
Sourcepub fn bot(&mut self, bot: bool) -> &mut MeUpdateBuilder<C>
pub fn bot(&mut self, bot: bool) -> &mut MeUpdateBuilder<C>
Sets whether to display this user as a bot.
Sourcepub fn cat(&mut self, cat: bool) -> &mut MeUpdateBuilder<C>
pub fn cat(&mut self, cat: bool) -> &mut MeUpdateBuilder<C>
Sets whether to display this user as a cot.
Sourcepub fn inject_featured_note(
&mut self,
inject_featured_note: bool,
) -> &mut MeUpdateBuilder<C>
pub fn inject_featured_note( &mut self, inject_featured_note: bool, ) -> &mut MeUpdateBuilder<C>
Sets whether to display featured notes in the timeline.
Sourcepub fn always_mark_nsfw(
&mut self,
always_mark_nsfw: bool,
) -> &mut MeUpdateBuilder<C>
pub fn always_mark_nsfw( &mut self, always_mark_nsfw: bool, ) -> &mut MeUpdateBuilder<C>
Sets whether to mark uploaded media as NSFW by default.
Sourcepub fn no_crawle(&mut self, no_crawle: bool) -> &mut MeUpdateBuilder<C>
Available on crate feature 12-60-0 only.
pub fn no_crawle(&mut self, no_crawle: bool) -> &mut MeUpdateBuilder<C>
12-60-0 only.Sets whether to ask search engines not to index this user’s contents.
Sourcepub fn muted_words(
&mut self,
muted_words: impl Into<Query<String>>,
) -> &mut MeUpdateBuilder<C>
pub fn muted_words( &mut self, muted_words: impl Into<Query<String>>, ) -> &mut MeUpdateBuilder<C>
Sets the muted words for this user.